@@ -204,24 +204,47 @@ def lectures(info, pensum=None):
         l['date'] = d
         l['preceded_by_holiday'] = i == holiday
         if not continuing_education():
+            ehw = int(info.get('extraordinary_holiday_week', -1))
+            if 'extraordinary_holiday_week' in info and int(lecture_info[i]['number']) == int(info['extraordinary_holiday_week']) and ehw == 13:
+
+                dow = int(info['day_of_week'])
+                if dow == 4:  # friday
+                    d2 = d + timedelta(days=4)  #
+                    l['month'] = d2.strftime('%B')
+                    l['day'] = d2.day
+                    l['date'] = d2
+                    l['extraordinary'] = True
+
             d = d + ow
+
+
             if i == holiday - 1: d = d + ow
             if d.month == 5 and d.day == 8: # grundlovsdag
                 d += timedelta(days=4)
+            # print(lecture_info[i]['number'],  info['extraordinary_holiday_week'])
+
+
+                # print("extraordinary!")
+            # pass
+
+
+
         else:
             d = d + timedelta(days=dd[i-0] if i > 1 else 0)
             d = d.replace(hour=ice['hour'][i-1], minute=ice['minute'][i-1])
 
-        info = lecture_info[i]
 
-        ir = info.get('reading', "")
-        info['reading_long'] = ir.replace("C", "Chapter ") if ir else ""
 
-        hwp =  info['homework_problems']
-        info['homework_problems_long'] = hwp.replace("P", "Problem ") if hwp else ""
-        if info["learning_objectives"]:
-            info["learning_objectives"] = [s.strip() for s in info["learning_objectives"].split("\n")]
-        l.update(info)
+        linfo = lecture_info[i]
+
+        ir = linfo.get('reading', "")
+        linfo['reading_long'] = ir.replace("C", "Chapter ") if ir else ""
+
+        hwp =  linfo['homework_problems']
+        linfo['homework_problems_long'] = hwp.replace("P", "Problem ") if hwp else ""
+        if linfo["learning_objectives"]:
+            linfo["learning_objectives"] = [s.strip() for s in linfo["learning_objectives"].split("\n")]
+        l.update(linfo)
         lectures.append(l)
     return lectures, pensum
 
@@ -255,7 +278,6 @@ def class_information():
     continuing_education_mode = core_conf['continuing_education_mode']
     faq = xlsx_to_dicts(paths['information.xlsx'], sheet='faq')
 
-
     d = {'year': year(),
          'piazza': piazza, # deprecated.
          'course_number': course_number,
