@@ -165,8 +165,9 @@ def make_lectures(week=None, mode=0, gather_pdf_out=True, gather_sixup=True, mak
         pdf_out = slider.latexmk(lecture_texfile, Linux=Linux)
         all_pdfs.append( (w,pdf_out))
 
-    handle_pdf_collection(paths, all_pdfs, gather_pdf_out=gather_pdf_out, gather_sixup=gather_sixup, odir=odex)
-
+    if len(all_pdfs) > 0:
+        handle_pdf_collection(paths, all_pdfs, gather_pdf_out=gather_pdf_out, gather_sixup=gather_sixup, odir=odex)
+# http://piazza.com/dtu.dk/spring2023/02465/home
 
 def handle_pdf_collection(paths, all_pdfs, gather_pdf_out, gather_sixup, odir):
     tmp_dir = paths['lectures'] + '/Collected/tmp'
@@ -262,6 +263,9 @@ def get_hash_from_base(base):
             actual_files[rel]['hash'] = source[rel]['hash']
     return actual_files
 
+def _ensure_target_dir_exists(out):
+    if not os.path.isdir(os.path.dirname(out)):
+        os.makedirs(os.path.dirname(out))
 
 # @profile
 def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compile_templates=True,shallow=True):
@@ -272,7 +276,7 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
     from jinjafy.cache import cache_contains_file, cache_update_file
     from slider.convert import svg2pdf, pdfcrop
     from slider import convert
-    import filecmp
+    # import filecmp
 
     t0 = time.time()
     shared_base = paths['shared']
@@ -300,11 +304,13 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
 
             # update_source_cache = True
     # Perform sync here.
+
     for rel in source:
         if rel.endswith("_partial.tex"):
             continue
 
         if rel not in target or target[rel]['hash'] != source[rel]['hash']:
+            _ensure_target_dir_exists( output_dir + "/" + rel)
             print(" -> ", output_dir + "/" + rel)
             shutil.copy(shared_base +"/" + rel, output_dir + "/" + rel)
             target[rel] = source[rel].copy()
@@ -320,8 +326,6 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
                 target[rel]['hash'] = hash_file_(output_dir + "/" + rel)
                 target[rel]['mtime'] = os.path.getmtime(output_dir + "/" + rel)
 
-    # Save the cache.
-
     with open(shared_base + "/sharedcache.pkl", 'wb') as f:
         pickle.dump(source, f)
 
@@ -552,24 +556,30 @@ def mvfiles(source_dir, dest_dir):
             shutil.copy(full_file_name, os.path.dirname(dest_dir))
 
 # @profile
-def make_webpage(dosvg=True):
+def make_webpage(dosvg=True, upload=True):
     cinfo = class_information()
     paths = get_paths()
     fix_shared(paths, output_dir=os.path.dirname(paths['homepage_out']), pdf2png=True, dosvg=dosvg)
     wdir = paths['homepage_template']
-    jinjafy_template(cinfo, file_in=wdir, file_out=paths['homepage_out'])
+
+
     print("Instructors for course: ")
     s = ""
     for dex,i in enumerate(cinfo['instructors']):
         if dex > 0:
             s += "; "
         s += i['email']
+        cinfo['instructors'][dex]['ok'] = i['email'] not in [t['email'] for t in cinfo['teachers'] ]
 
+    jinjafy_template(cinfo, file_in=wdir, file_out=paths['homepage_out'])
     blrb = os.path.dirname(paths['homepage_template']) +"/homepage_widget_blurb_template.html"
     if os.path.exists( blrb):
         jinjafy_template(cinfo, file_in=blrb, file_out=blrb.replace("_template.html", ".html"))
-    print(s)
 
+    if upload:
+        import subprocess
+        cmd = f"cd {os.path.dirname(paths['homepage_template'] )} && rsync --delete --rsh=ssh -av ./ tuhe@thinlinc.compute.dtu.dk:/www/docs/courses/02465/"
+        subprocess.run([cmd], shell=True)
 
 # This should probably  be moved into jinjafy
 def tt(value):
